ResponseContentDigest

Trait ResponseContentDigest 

pub trait ResponseContentDigest {
    type Error;
    type PassthroughResponse;

    // Required methods
    fn set_content_digest(
        self,
        cd_type: &ContentDigestType,
    ) -> impl Future<Output = Result<Self::PassthroughResponse, Self::Error>> + Send
       where Self: Sized;
    fn verify_content_digest(
        self,
    ) -> impl Future<Output = Result<Self::PassthroughResponse, Self::Error>> + Send
       where Self: Sized;
}
A trait to set the http content digest in response in base64

Required Associated Types

Required Methods

fn set_content_digest( self, cd_type: &ContentDigestType, ) -> impl Future<Output = Result<Self::PassthroughResponse, Self::Error>> + Send
where Self: Sized,

Set the content digest in the response

fn verify_content_digest( self, ) -> impl Future<Output = Result<Self::PassthroughResponse, Self::Error>> + Send
where Self: Sized,

Verify the content digest in the response and returns self if it’s valid otherwise returns error

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<B> ResponseContentDigest for Response<B>
where B: Body + Send, <B as Body>::Data: Send,

Implementors